import type { OptionHTMLAttributes, CSSProperties } from 'react';
import type { ClassNames } from './interface';
declare type ModifyProp<T, M> = {
    [K in keyof T]: M;
};
declare type InlineStyles = ModifyProp<ClassNames, CSSProperties>;
declare type Options = OptionHTMLAttributes<any>[];
declare type Dispatcher<T> = React.Dispatch<React.SetStateAction<T>>;
declare type TableSchema = {
    id: string;
    name: string;
    readOnly?: boolean;
    getRow?: (row: {
        [key: string]: any;
    }) => any;
} & ({
    type?: 'text';
    dataFormator?: (data: string) => string;
    searchable?: boolean;
} | {
    type: 'number';
    dataFormator?: (data: number) => number;
    searchable?: boolean;
} | {
    type: 'select';
    options: Options;
});
declare type KeyOfTableSchema = keyof TableSchema;
declare type TableHeadCellProps<T = TableSchema> = T & {
    tableData: T[];
    setDraftTableData: Dispatcher<T[]>;
    classes?: ClassNames;
    styles?: InlineStyles;
    sortable?: boolean;
};
declare type TableBodyCellProps = TableSchema & {
    updateTableData: (value: number | string) => void;
    updateCursor: () => void;
    isSelected: boolean;
    data: number | string;
    dataFormator?: (data: any) => any;
    options?: Options;
    classes?: ClassNames;
    styles?: InlineStyles;
};
export type { Options, TableSchema, KeyOfTableSchema, Dispatcher, TableHeadCellProps, TableBodyCellProps, InlineStyles };
